==> ejc-cfs-impl-3.0.0-20210630.062755-111-sources.jar: com/ejianc/foundation/cfs/bean/CustomListEntity.java <==
package com.ejianc.foundation.cfs.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 配置列表项
 * 
 * @author lyj
 *
 */
@TableName("ejc_cfs_list")
public class CustomListEntity extends BaseEntity {

	private static final long serialVersionUID = -8878993756357134195L;

	@TableField(value = "app_id")
	private Long appId; // 应用Id

	@TableField(value = "column_id")
	private Long columnId; // 列id

	@TableField(value = "column_property")
	private String columnProperty; // 列属性

	@TableField(value = "column_name")
	private String columnName; // 列名称

	@TableField(value = "column_type")
	private String columnType; // 列类型

	@TableField(value = "column_format")
	private String columnFormat; // 列显示格式(当为时间显示时分秒，小数位的显示数量等等)

	@TableField(value = "inner_filter")
	private Boolean innerFilter; // 是否支持搜索

	@TableField(value = "total")
	private Boolean total; // 是否数据汇总

	@TableField(value = "view_detail")
	private Boolean viewDetail; // 是否支持查看详情

	@TableField(value = "align")
	private String align; // 对齐方式

	@TableField(value = "suffix_str")
	private String suffixStr; // 显示后缀

	@TableField(value = "customize")
	private String customize; // 自定义
	
	@TableField(value = "sequence")
	private Integer sequence; // 排序号

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getColumnId() {
		return columnId;
	}

	public void setColumnId(Long columnId) {
		this.columnId = columnId;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public String getColumnProperty() {
		return columnProperty;
	}

	public void setColumnProperty(String columnProperty) {
		this.columnProperty = columnProperty;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public String getColumnType() {
		return columnType;
	}

	public void setColumnType(String columnType) {
		this.columnType = columnType;
	}

	public String getColumnFormat() {
		return columnFormat;
	}

	public void setColumnFormat(String columnFormat) {
		this.columnFormat = columnFormat;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Boolean getTotal() {
		return total;
	}

	public void setTotal(Boolean total) {
		this.total = total;
	}

	public Boolean getViewDetail() {
		return viewDetail;
	}

	public void setViewDetail(Boolean viewDetail) {
		this.viewDetail = viewDetail;
	}

	public String getAlign() {
		return align;
	}

	public void setAlign(String align) {
		this.align = align;
	}

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getCustomize() {
		return customize;
	}

	public void setCustomize(String customize) {
		this.customize = customize;
	}

}

==> ejc-cfs-impl-3.0.0-20240314.085926-189-sources.jar: com/ejianc/foundation/cfs/bean/CustomListEntity.java <==
package com.ejianc.foundation.cfs.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 配置列表项
 * 
 * @author lyj
 *
 */
@TableName("ejc_cfs_list")
public class CustomListEntity extends BaseEntity {

	private static final long serialVersionUID = -8878993756357134195L;

	@TableField(value = "app_id")
	private Long appId; // 应用Id

	@TableField(value = "column_id")
	private Long columnId; // 列id

	@TableField(value = "column_property")
	private String columnProperty; // 列属性

	@TableField(value = "column_name")
	private String columnName; // 列名称

	@TableField(value = "column_type")
	private String columnType; // 列类型

	@TableField(value = "column_format")
	private String columnFormat; // 列显示格式(当为时间显示时分秒，小数位的显示数量等等)

	@TableField(value = "inner_filter")
	private Boolean innerFilter; // 是否支持搜索

	@TableField(value = "total")
	private Boolean total; // 是否数据汇总

	@TableField(value = "view_detail")
	private Boolean viewDetail; // 是否支持查看详情

	@TableField(value = "align")
	private String align; // 对齐方式

	@TableField(value = "suffix_str")
	private String suffixStr; // 显示后缀

	@TableField(value = "customize")
	private String customize; // 自定义
	
	@TableField(value = "sequence")
	private Integer sequence; // 排序号

	@TableField(value = "sub_export_relation")
	private Boolean subExportRelation; // 导出数据该字段是否关联到子表

	public Boolean getSubExportRelation() {
		return subExportRelation;
	}

	public void setSubExportRelation(Boolean subExportRelation) {
		this.subExportRelation = subExportRelation;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getColumnId() {
		return columnId;
	}

	public void setColumnId(Long columnId) {
		this.columnId = columnId;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public String getColumnProperty() {
		return columnProperty;
	}

	public void setColumnProperty(String columnProperty) {
		this.columnProperty = columnProperty;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public String getColumnType() {
		return columnType;
	}

	public void setColumnType(String columnType) {
		this.columnType = columnType;
	}

	public String getColumnFormat() {
		return columnFormat;
	}

	public void setColumnFormat(String columnFormat) {
		this.columnFormat = columnFormat;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Boolean getTotal() {
		return total;
	}

	public void setTotal(Boolean total) {
		this.total = total;
	}

	public Boolean getViewDetail() {
		return viewDetail;
	}

	public void setViewDetail(Boolean viewDetail) {
		this.viewDetail = viewDetail;
	}

	public String getAlign() {
		return align;
	}

	public void setAlign(String align) {
		this.align = align;
	}

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getCustomize() {
		return customize;
	}

	public void setCustomize(String customize) {
		this.customize = customize;
	}

}
